Class: OKComputer::SizeThresholdCheck

Inherits:
Check
  • Object
show all
Defined in:
lib/okcomputer/built_in_checks/size_threshold_check.rb

Direct Known Subclasses

DelayedJobBackedUpCheck, ResqueBackedUpCheck

Constant Summary

Constants inherited from Check

Check::CALL_DEPRECATION_MESSAGE, Check::CheckNotDefined

Instance Attribute Summary collapse

Attributes inherited from Check

#failure_occurred, #message, #registrant_name

Instance Method Summary collapse

Methods inherited from Check

#clear, #mark_failure, #mark_message, #run, #success?, #to_json, #to_text

Constructor Details

#initialize(name, threshold, &size_proc) ⇒ SizeThresholdCheck

Public: Initialize a check for a backed-up Resque queue

name - the value that this check should be refered to as threshold - An Integer to compare the size object's count against to consider it backed up size_proc - The block/proc that returns an integer to compare against

Examples

SizeThresholdCheck.new("some queue", 2) do
 Queue.new("my_queue").size
end


20
21
22
23
24
# File 'lib/okcomputer/built_in_checks/size_threshold_check.rb', line 20

def initialize(name, threshold, &size_proc)
  self.size_proc = size_proc
  self.threshold = Integer(threshold)
  self.name = name
end

Instance Attribute Details

#name ⇒ Object

Returns the value of attribute name.



5
6
7
# File 'lib/okcomputer/built_in_checks/size_threshold_check.rb', line 5

def name
  @name
end

#size_proc ⇒ Object

Returns the value of attribute size_proc.



3
4
5
# File 'lib/okcomputer/built_in_checks/size_threshold_check.rb', line 3

def size_proc
  @size_proc
end

#threshold ⇒ Object

Returns the value of attribute threshold.



4
5
6
# File 'lib/okcomputer/built_in_checks/size_threshold_check.rb', line 4

def threshold
  @threshold
end

Instance Method Details

#check ⇒ Object

Public: Check whether the given queue is backed up



27
28
29
30
31
32
33
34
# File 'lib/okcomputer/built_in_checks/size_threshold_check.rb', line 27

def check
  if size <= threshold
    mark_message " #{name} at reasonable level (#{size})"
  else
    mark_failure
    mark_message "#{name} is over #{threshold} threshold! (#{size})"
  end
end

#size ⇒ Object

Public: The number of jobs in the check's queue



37
38
39
# File 'lib/okcomputer/built_in_checks/size_threshold_check.rb', line 37

def size
  Integer(size_proc.call)
end